@@ -182,7 +182,9 @@ def describe_stack_dynamically(cloudformation, cluster):
     try:
         # cloudformation = boto3.client('cloudformation')
         # stack_name = "%s-eks-worker-nodes" % (args.environment)
+        print('Hi')
         response = cloudformation.describe_stacks()
+        print(response)
 
         clusterStackNames = []
         stacksINFO = []
